mercurial/similar.py
changeset 32202 ded48ad55146
parent 31584 985a98c6bad0
child 38348 cd196be26cb7
--- a/mercurial/similar.py	Wed Apr 26 21:56:47 2017 +0900
+++ b/mercurial/similar.py	Wed Apr 26 22:03:37 2017 +0900
@@ -9,7 +9,6 @@
 
 from .i18n import _
 from . import (
-    bdiff,
     mdiff,
 )
 
@@ -56,10 +55,10 @@
 def _score(fctx, otherdata):
     orig, lines = otherdata
     text = fctx.data()
     # bdiff.blocks() returns blocks of matching lines
     # count the number of bytes in each
     equal = 0
-    matches = bdiff.blocks(text, orig)
+    matches = mdiff.blocks(text, orig)
     for x1, x2, y1, y2 in matches:
         for line in lines[y1:y2]:
             equal += len(line)
@@ -56,10 +55,10 @@
     orig, lines = otherdata
     text = fctx.data()
-    # bdiff.blocks() returns blocks of matching lines
+    # mdiff.blocks() returns blocks of matching lines
     # count the number of bytes in each
     equal = 0